@@ -23,22 +23,7 @@ int main(int ac, char**av) {
 			printf("Error on %s: %s\n", av[i], gai_strerror(e));
 		} else {
 			for(rp=res; rp != NULL; rp = rp->ai_next) {
-				struct sockaddr_in* in4;
-				struct sockaddr_in6* in6;
-				void* addr;
-
-				switch(rp->ai_family) {
-				case AF_INET:
-					in4 = (struct sockaddr_in*)rp->ai_addr;
-					addr = &(in4->sin_addr);
-					break;
-				case AF_INET6:
-					in6 = (struct sockaddr_in6*)rp->ai_addr;
-					addr = &(in6->sin6_addr);
-					break;
-				}
-				inet_ntop(rp->ai_family, addr, host, rp->ai_addrlen);
-				//getnameinfo(rp->ai_addr, rp->ai_addrlen, host, NI_MAXHOST, serv, NI_MAXSERV, NI_NUMERICHOST);
+				getnameinfo(rp->ai_addr, rp->ai_addrlen, host, NI_MAXHOST, serv, NI_MAXSERV, NI_NUMERICHOST);
 				printf("%s\n", host);
 			}
 		}
